@@ -1,7 +1,9 @@
 import pandas as pd
 from pm4pymdl.algo.mvp.utils import filter_metaclass
+from pm4pymdl.algo.mvp.utils import succint_mdl_to_exploded_mdl
 
-def apply(df, obj_type, act1, act2, parameters=None):
+
+def apply(df, obj_type, act1, act2, minp, maxp, parameters=None):
     try:
         if df.type == "succint":
             df = succint_mdl_to_exploded_mdl.apply(df)
@@ -18,6 +20,13 @@ def apply(df, obj_type, act1, act2, parameters=None):
     red_df_shifted.columns = [str(col) + '_2' for col in red_df_shifted.columns]
     stacked_df = pd.concat([red_df, red_df_shifted], axis=1)
     stacked_df["@@path"] = stacked_df["event_activity"] + "," + stacked_df["event_activity_2"]
+    stacked_df["@@diff"] = (stacked_df["event_timestamp_2"] - stacked_df["event_timestamp"]).astype('timedelta64[s]')
     stacked_df = stacked_df[stacked_df["@@path"] == act1+","+act2]
+    #stacked_df.info()
+    #print(minp, type(minp))
+    #print(maxp, type(maxp))
+    #print(stacked_df["@@diff"])
+    stacked_df = stacked_df[minp <= stacked_df["@@diff"]]
+    stacked_df = stacked_df[stacked_df["@@diff"] <= maxp]
     filt_df = red_df[red_df["event_id"].isin(stacked_df["event_id"]) | red_df["event_id"].isin(stacked_df["event_id_2"])]
     return filter_metaclass.do_filtering(df, filt_df)
