@@ -1,7 +1,8 @@
 from pm4pymdl.algo.mvp.utils import exploded_mdl_to_succint_mdl, succint_mdl_to_exploded_mdl
 from copy import deepcopy
+import pandas as pd
 
-def apply(df, file_path, parameters=None):
+def apply(df, file_path, obj_df=None, parameters=None):
     if parameters is None:
         parameters = {}
 
@@ -16,6 +17,9 @@ def apply(df, file_path, parameters=None):
         if conversion_needed:
             df = exploded_mdl_to_succint_mdl.apply(df)
 
+        if obj_df is not None:
+            df = pd.concat([df, obj_df])
+
         df.to_csv(file_path, index=False, sep=',', quotechar='\"')
     else:
         from pm4py.objects.log.exporter.parquet import factory as parquet_exporter
@@ -29,6 +33,10 @@ def apply(df, file_path, parameters=None):
 
         if conversion_needed:
             df = succint_mdl_to_exploded_mdl.apply(df)
+
+        if obj_df is not None:
+            df = pd.concat([df, obj_df])
+
         new_parameters = deepcopy(parameters)
         new_parameters["compression"] = "gzip"
         parquet_exporter.export_df(df, file_path, parameters=new_parameters)
